<?php

namespace Lavalite\Product\Forms;

use Litepie\Form\FormInterpreter;

class Product extends FormInterpreter
{

    /**
     * Sets the form and form elements.
     * @return null.
     */
    public static function setAttributes()
    {

        self::$urls = [
            'new' => [
                'url' => guard_url('product/product/new'),
                'method' => 'GET',
            ],
            'create' => [
                'url' => guard_url('product/product/create'),
                'method' => 'GET',
            ],
            'store' => [
                'url' => guard_url('product/product'),
                'method' => 'POST',
            ],
            'update' => [
                'url' => guard_url('product/product'),
                'method' => 'PUT',
            ],
            'list' => [
                'url' => guard_url('product/product'),
                'method' => 'GET',
            ],
            'delete' => [
                'url' => guard_url('product/product'),
                'method' => 'DELETE',
            ],
        ];
        self::$search = [
            'name' => [
                "type" => 'text',
                "label" => trans('product::product.label.name'),
                "placeholder" => trans('product::product.placeholder.name'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "4",
                "roles" => [],
            ]
        ];
        self::$groups = [
            'main' => trans('product::product.groups.main'),
            'details' => trans('product::product.groups.details'),
            'images' => trans('product::product.groups.images'),
            'settings' => trans('product::product.groups.settings'),
        ];
        self::$list = [
            [
                'key' => "ref",
                'label' => trans('product::product.label.ref'),
                'sortable' => 'true',
                'roles' => [],
            ],
            [
                'key' => "id",
                'label' => trans('product::product.label.id'),
                'sortable' => 'true',
                'roles' => [],
            ],
            [
                'key' => "name",
                'label' => trans('product::product.label.name'),
                'sortable' => 'true',
                'roles' => [],
            ],
            [
                'key' => "status",
                'label' => trans('product::product.label.status'),
                'sortable' => 'true',
                'roles' => [],
            ],
        ];
        self::$fields = [
                'title' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('product::product.label.title'),
                "placeholder" => trans('product::product.placeholder.title'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'subtitle' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('product::product.label.subtitle'),
                "placeholder" => trans('product::product.placeholder.subtitle'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'description' => [
                "element" => 'html_editor',
                "type" => 'html_editor',
                "label" => trans('product::product.label.description'),
                "placeholder" => trans('product::product.placeholder.description'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'icon' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('product::product.label.icon'),
                "placeholder" => trans('product::product.placeholder.icon'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'features_icon' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('product::product.label.features_icon'),
                "placeholder" => trans('product::product.placeholder.features_icon'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'color' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('product::product.label.color'),
                "placeholder" => trans('product::product.placeholder.color'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'meta_title' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('product::product.label.meta_title'),
                "placeholder" => trans('product::product.placeholder.meta_title'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'meta_description' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('product::product.label.meta_description'),
                "placeholder" => trans('product::product.placeholder.meta_description'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'meta_tags' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('product::product.label.meta_tags'),
                "placeholder" => trans('product::product.placeholder.meta_tags'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'meta_subtitle' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('product::product.label.meta_subtitle'),
                "placeholder" => trans('product::product.placeholder.meta_subtitle'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'highlights' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('product::product.label.highlights'),
                "placeholder" => trans('product::product.placeholder.highlights'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'features' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('product::product.label.features'),
                "placeholder" => trans('product::product.placeholder.features'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'images' => [
                "element" => 'file',
                "type" => 'images',
                "label" => trans('product::product.label.images'),
                "placeholder" => trans('product::product.placeholder.images'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'demo_screenshots' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('product::product.label.demo_screenshots'),
                "placeholder" => trans('product::product.placeholder.demo_screenshots'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'login_details' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('product::product.label.login_details'),
                "placeholder" => trans('product::product.placeholder.login_details'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'testimonials' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('product::product.label.testimonials'),
                "placeholder" => trans('product::product.placeholder.testimonials'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'published' => [
                "element" => 'select',
                "type" => 'select',
                "label" => trans('product::product.label.published'),
                "placeholder" => trans('product::product.placeholder.published'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
        ];

        return new static();
    }
}
