<?php

namespace Lavalite\Product\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;
use Lavalite\Product\Repositories\Eloquent\Filters\ProductPublicFilter;
use Lavalite\Product\Repositories\Eloquent\Presenters\ProductListPresenter;
use Lavalite\Product\Interfaces\ProductRepositoryInterface;

class ProductPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(ProductRepositoryInterface $product)
    {
        parent::__construct();
        $this->modules = $this->modules(config('lavalite.product.modules'), 'product', guard_url('product'));
        $this->repository = $product;

    }

    /**
     * Show product's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(ProductPublicFilter::class)
            ->setPresenter(ProductListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('product::product.names'))
            ->view('product::public.product.index')
            ->data(compact('data', 'meta', 'modules'))
            ->output();
    }


    /**
     * Show product.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();
        $modules = $this->modules;

        return $this->response->setMetaTitle($data['name'] . trans('product::product.name'))
            ->view('product::public.product.show')
            ->data(compact('data', 'modules'))
            ->output();
    }

}
